==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/SubnetSharedPublicIpAddressConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Configuration for public IP address sharing.
 * @property allowedPorts Backend ports that virtual machines on this subnet are allowed to expose
 */
public data class SubnetSharedPublicIpAddressConfigurationArgs(
    public val allowedPorts: Output<List<PortArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs =
        com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs.builder()
            .allowedPorts(
                allowedPorts?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SubnetSharedPublicIpAddressConfigurationArgs].
 */
@PulumiTagMarker
public class SubnetSharedPublicIpAddressConfigurationArgsBuilder internal constructor() {
    private var allowedPorts: Output<List<PortArgs>>? = null

    /**
     * @param value Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("ymymeyhvhreghiaa")
    public suspend fun allowedPorts(`value`: Output<List<PortArgs>>) {
        this.allowedPorts = value
    }

    @JvmName("umvfpnwklocghumu")
    public suspend fun allowedPorts(vararg values: Output<PortArgs>) {
        this.allowedPorts = Output.all(values.asList())
    }

    /**
     * @param values Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("txxrqsfvfvtkgvia")
    public suspend fun allowedPorts(values: List<Output<PortArgs>>) {
        this.allowedPorts = Output.all(values)
    }

    /**
     * @param value Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("igtkbmxqrxetrska")
    public suspend fun allowedPorts(`value`: List<PortArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedPorts = mapped
    }

    /**
     * @param argument Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("jxdurfkfxpchafpb")
    public suspend fun allowedPorts(argument: List<suspend PortArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { PortArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allowedPorts = mapped
    }

    /**
     * @param argument Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("wjphjlkshielsivq")
    public suspend fun allowedPorts(vararg argument: suspend PortArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { PortArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allowedPorts = mapped
    }

    /**
     * @param argument Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("ygmegfrakjbxnurf")
    public suspend fun allowedPorts(argument: suspend PortArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PortArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allowedPorts = mapped
    }

    /**
     * @param values Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("xevxsuawowvhohmt")
    public suspend fun allowedPorts(vararg values: PortArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedPorts = mapped
    }

    internal fun build(): SubnetSharedPublicIpAddressConfigurationArgs =
        SubnetSharedPublicIpAddressConfigurationArgs(
            allowedPorts = allowedPorts,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/SubnetSharedPublicIpAddressConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Configuration for public IP address sharing.
 * @property allowedPorts Backend ports that virtual machines on this subnet are allowed to expose
 */
public data class SubnetSharedPublicIpAddressConfigurationArgs(
    public val allowedPorts: Output<List<PortArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs =
        com.pulumi.azurenative.devtestlab.inputs.SubnetSharedPublicIpAddressConfigurationArgs.builder()
            .allowedPorts(
                allowedPorts?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SubnetSharedPublicIpAddressConfigurationArgs].
 */
@PulumiTagMarker
public class SubnetSharedPublicIpAddressConfigurationArgsBuilder internal constructor() {
    private var allowedPorts: Output<List<PortArgs>>? = null

    /**
     * @param value Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("llnbakskmnmbxsva")
    public suspend fun allowedPorts(`value`: Output<List<PortArgs>>) {
        this.allowedPorts = value
    }

    @JvmName("smibgfmdnlaodtst")
    public suspend fun allowedPorts(vararg values: Output<PortArgs>) {
        this.allowedPorts = Output.all(values.asList())
    }

    /**
     * @param values Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("clmimoskltlkbdrm")
    public suspend fun allowedPorts(values: List<Output<PortArgs>>) {
        this.allowedPorts = Output.all(values)
    }

    /**
     * @param value Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("jtogecvqdtngobrm")
    public suspend fun allowedPorts(`value`: List<PortArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedPorts = mapped
    }

    /**
     * @param argument Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("lscuhsdypavkmnsj")
    public suspend fun allowedPorts(argument: List<suspend PortArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { PortArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allowedPorts = mapped
    }

    /**
     * @param argument Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("qcxlwrhnxiperhkp")
    public suspend fun allowedPorts(vararg argument: suspend PortArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { PortArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allowedPorts = mapped
    }

    /**
     * @param argument Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("cbyujrkciliapurq")
    public suspend fun allowedPorts(argument: suspend PortArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PortArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allowedPorts = mapped
    }

    /**
     * @param values Backend ports that virtual machines on this subnet are allowed to expose
     */
    @JvmName("xwumvthsqqcfqmvt")
    public suspend fun allowedPorts(vararg values: PortArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedPorts = mapped
    }

    internal fun build(): SubnetSharedPublicIpAddressConfigurationArgs =
        SubnetSharedPublicIpAddressConfigurationArgs(
            allowedPorts = allowedPorts,
        )
}
